@@ -35,6 +35,13 @@ atoxgr_criteria_ctcv5 %>%
     display_vars = exprs(TERM)
   )
 
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+atoxgr_criteria_ctcv6 %>%
+  filter(!is.na(TERM)) %>%
+  dataset_vignette(
+    display_vars = exprs(TERM)
+  )
+
 ## ----eval=TRUE, echo=FALSE----------------------------------------------------
 atoxgr_criteria_daids %>%
   filter(!is.na(TERM)) %>%
@@ -170,9 +177,9 @@ adlb <- adlb %>%
 
 ## ----eval=TRUE, echo=FALSE----------------------------------------------------
 atoxgr_criteria_ctcv4 %>%
-  filter(!is.na(SI_UNIT_CHECK)) %>%
+  filter(!is.na(UNIT_CHECK)) %>%
   dataset_vignette(
-    display_vars = exprs(TERM, SI_UNIT_CHECK),
+    display_vars = exprs(TERM, UNIT_CHECK),
   )
 
 ## ----eval=TRUE----------------------------------------------------------------
@@ -204,7 +211,7 @@ atoxgr_criteria_ctcv4 %>%
 atoxgr_criteria_ctcv4 %>%
   filter(str_detect(TERM, "INR")) %>%
   dataset_vignette(
-    display_vars = exprs(TERM, Grade_1)
+    display_vars = exprs(TERM, GRADE_1)
   )
 
 ## ----eval=TRUE, echo=FALSE----------------------------------------------------
@@ -218,14 +225,22 @@ atoxgr_criteria_ctcv4 %>%
 atoxgr_criteria_ctcv4 %>%
   filter(str_detect(TERM, "Hyperuricemia")) %>%
   dataset_vignette(
-    display_vars = exprs(TERM, Grade_1, Grade_3, COMMENT)
+    display_vars = exprs(TERM, GRADE_1, GRADE_3, COMMENT)
   )
 
 ## ----eval=TRUE, echo=FALSE----------------------------------------------------
 atoxgr_criteria_ctcv4 %>%
   filter(str_detect(TERM, "Hypokalemia")) %>%
   dataset_vignette(
-    display_vars = exprs(TERM, Grade_1, Grade_2, COMMENT)
+    display_vars = exprs(TERM, GRADE_1, GRADE_2, COMMENT)
+  )
+
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+atoxgr_criteria_ctcv4 %>%
+  filter(!is.na(COMMENT) & str_detect(TERM, "glycemia", negate = TRUE) &
+    str_detect(TERM, "calcemia", negate = TRUE)) %>%
+  dataset_vignette(
+    display_vars = exprs(TERM, GRADE_1, GRADE_2, GRADE_3, GRADE_4, COMMENT)
   )
 
 ## ----eval=TRUE, echo=FALSE----------------------------------------------------
@@ -239,7 +254,7 @@ atoxgr_criteria_ctcv5 %>%
 atoxgr_criteria_ctcv5 %>%
   filter(str_detect(TERM, "INR")) %>%
   dataset_vignette(
-    display_vars = exprs(TERM, Grade_1)
+    display_vars = exprs(TERM, GRADE_1)
   )
 
 ## ----eval=TRUE, echo=FALSE----------------------------------------------------
@@ -253,12 +268,12 @@ atoxgr_criteria_ctcv5 %>%
 atoxgr_criteria_ctcv5 %>%
   filter(str_detect(TERM, "Lipase") | str_detect(TERM, "amylase")) %>%
   dataset_vignette(
-    display_vars = exprs(TERM, Grade_2, Grade_3, Grade_4)
+    display_vars = exprs(TERM, GRADE_2, GRADE_3, GRADE_4)
   )
 
 ## ----eval=TRUE, echo=FALSE----------------------------------------------------
 atoxgr_criteria_ctcv5 %>%
-  filter(str_detect(TERM, "INR") | str_detect(TERM, "amylase")) %>%
+  filter(str_detect(TERM, "Lipase") | str_detect(TERM, "amylase")) %>%
   dataset_vignette(
     display_vars = exprs(TERM, COMMENT)
   )
@@ -267,14 +282,77 @@ atoxgr_criteria_ctcv5 %>%
 atoxgr_criteria_ctcv5 %>%
   filter(str_detect(TERM, "Hyperuricemia")) %>%
   dataset_vignette(
-    display_vars = exprs(TERM, Grade_1, Grade_3, COMMENT)
+    display_vars = exprs(TERM, GRADE_1, GRADE_3, COMMENT)
   )
 
 ## ----eval=TRUE, echo=FALSE----------------------------------------------------
 atoxgr_criteria_ctcv5 %>%
   filter(str_detect(TERM, "Hypokalemia") | str_detect(TERM, "Hyponatremia")) %>%
   dataset_vignette(
-    display_vars = exprs(TERM, Grade_1, Grade_2, Grade_3, COMMENT)
+    display_vars = exprs(TERM, GRADE_1, GRADE_2, GRADE_3, COMMENT)
+  )
+
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+atoxgr_criteria_ctcv5 %>%
+  filter(!is.na(COMMENT) & str_detect(TERM, "calcemia", negate = TRUE)) %>%
+  dataset_vignette(
+    display_vars = exprs(TERM, GRADE_1, GRADE_2, GRADE_3, GRADE_4, COMMENT)
+  )
+
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+atoxgr_criteria_ctcv6 %>%
+  filter(str_detect(TERM, "calcemia")) %>%
+  dataset_vignette(
+    display_vars = exprs(TERM, COMMENT)
+  )
+
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+atoxgr_criteria_ctcv6 %>%
+  filter(str_detect(TERM, "INR")) %>%
+  dataset_vignette(
+    display_vars = exprs(TERM, GRADE_1)
+  )
+
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+atoxgr_criteria_ctcv6 %>%
+  filter(str_detect(TERM, "INR")) %>%
+  dataset_vignette(
+    display_vars = exprs(TERM, COMMENT)
+  )
+
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+atoxgr_criteria_ctcv6 %>%
+  filter(str_detect(TERM, "Lipase") | str_detect(TERM, "amylase")) %>%
+  dataset_vignette(
+    display_vars = exprs(TERM, GRADE_2, GRADE_3, GRADE_4)
+  )
+
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+atoxgr_criteria_ctcv6 %>%
+  filter(str_detect(TERM, "Lipase") | str_detect(TERM, "amylase")) %>%
+  dataset_vignette(
+    display_vars = exprs(TERM, COMMENT)
+  )
+
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+atoxgr_criteria_ctcv6 %>%
+  filter(str_detect(TERM, "Hyperuricemia")) %>%
+  dataset_vignette(
+    display_vars = exprs(TERM, GRADE_1, GRADE_3, COMMENT)
+  )
+
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+atoxgr_criteria_ctcv6 %>%
+  filter(str_detect(TERM, "Hypokalemia") | str_detect(TERM, "Hyponatremia")) %>%
+  dataset_vignette(
+    display_vars = exprs(TERM, GRADE_1, GRADE_2, GRADE_3, COMMENT)
+  )
+
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+atoxgr_criteria_ctcv6 %>%
+  filter(!is.na(COMMENT) & str_detect(TERM, "calcemia", negate = TRUE)) %>%
+  dataset_vignette(
+    display_vars = exprs(TERM, GRADE_1, GRADE_2, GRADE_3, GRADE_4, COMMENT)
   )
 
 ## ----eval=TRUE, echo=FALSE----------------------------------------------------
@@ -316,7 +394,7 @@ atoxgr_criteria_daids %>%
 atoxgr_criteria_daids %>%
   filter(str_detect(TERM, "Lactate")) %>%
   dataset_vignette(
-    display_vars = exprs(TERM, Grade_1, Grade_1)
+    display_vars = exprs(TERM, GRADE_1, GRADE_1)
   )
 
 ## ----eval=TRUE, echo=FALSE----------------------------------------------------
@@ -330,6 +408,15 @@ atoxgr_criteria_daids %>%
 atoxgr_criteria_daids %>%
   filter(str_detect(COMMENT, "conver")) %>%
   dataset_vignette(
-    display_vars = exprs(TERM, FILTER, COMMENT)
+    display_vars = exprs(TERM, COMMENT)
+  )
+
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+atoxgr_criteria_daids %>%
+  filter(!is.na(COMMENT) & str_detect(COMMENT, "No criteria given", negate = TRUE) &
+    str_detect(COMMENT, "Did not grade", negate = TRUE)) %>%
+  arrange(TERM) %>%
+  dataset_vignette(
+    display_vars = exprs(TERM, COMMENT)
   )
 
